import Toolbar from '@mui/material/Toolbar'
import IconButton from '@mui/material/IconButton'
import MenuIcon from '@mui/icons-material/Menu';
import SearchIcon from '@mui/icons-material/Search';
import InputBase from '@mui/material/InputBase';
import ArrowBackIcon from '@mui/icons-material/ArrowBack';
import { styled } from '@mui/material/styles';
import { makeStyles } from '@material-ui/core'
import React, { useState, useRef, useEffect } from 'react';
import { createPortal } from 'react-dom';

import SmallMenuBar from './ChatsList/SmallMenuBar'
import SearchBar from './SearchBar'
import ChatsList from './ChatsList'
import MenuBar from './ChatsList/MenuBar'



const Search = styled('div')(({ theme }:any) => ({
  position: 'relative',
  borderRadius: '20px',
  backgroundColor: '#f1f0f0',
  '&:hover': {
    backgroundColor: '#f5f5f5',
    color:'#2184f7',
  }, 
  marginLeft: 0,
  width: '100%',
  [theme.breakpoints.up('sm')]: {
    marginLeft: theme.spacing(1),
    width: 'auto',
  },
}));

const SearchIconWrapper = styled('div')(({ theme }) => ({
  padding: theme.spacing(0, 2),
  height: '100%',
  position: 'absolute',
  pointerEvents: 'none',
  display: 'flex',
  alignItems: 'center',
  justifyContent: 'center',
}));

const StyledInputBase = styled(InputBase)(({ theme }) => ({
    color: 'inherit',
  '& .MuiInputBase-input': { 
    fontWeight: 500,
    borderRadius: '20px',
    padding: theme.spacing(1, 1, 1, 0),
    paddingLeft: `calc(1em + ${theme.spacing(4)})`,
    transition: theme.transitions.create('width'),
    width: '100%',
    [theme.breakpoints.up('sm')]: {
      width: '35ch',
      '&:focus': {
        outline: '2px solid  #2184f7',
      },
    },
  },
}));

const useStyles = makeStyles({
  toolBar: {
    color:'#b1aeae',
  },
  iconBtn: {
    '&:hover': {
      transform: 'rotate(180deg)',
      transition: 'all 250ms ease-out ',
    }
  },
  iconArrow: {
    '&:hover': {
      transform: 'rotate(360deg)',
      transition: 'all 250ms ease-out ',
    }
  },
})

const ContactsBar = () => {
    const classes = useStyles()
    const [isOpen, setIsOpen] = useState<boolean>(false)
    const [isMenu, setIsMenu] = useState<boolean>(false)
    const [isMenuSm, setIsMenuSm] = useState<boolean>(false);
    const [value, setValue] = useState<string>('')
    const modalRoot = useRef<HTMLDivElement|null>(null);
    const handleFocus = (): void => setIsOpen(true)
    const handleClick = (): void => {
    if(!isOpen) return setIsMenu(!isMenu)
       setIsOpen(false)
    }
    const handleSearch = (e: React.ChangeEvent<HTMLInputElement>):void => setValue(e.target.value)
    const handleEnterOpenMenuSm = (): void => {
    if(!isMenuSm)setIsMenuSm(true)
    }
    const handleLeaveCloseMenuSm = (e: any): void => {
      if(isMenuSm&&e.pageX > 470)setIsMenuSm(false)
    }

  useEffect(() => {
    const handleCloseModal = (e:any) => {
      console.log(e.target)
      if(e.target.id === 'overlay')  setIsMenu(false)
    }
    if (!modalRoot.current) {
    const modal = document.getElementById('modal-root') as HTMLDivElement | null
      if (modal) {
      modal.addEventListener('click',handleCloseModal)
      modalRoot.current = modal
       }     
    }
    return () => {
      if (modalRoot.current) {
      modalRoot.current.removeEventListener('click',handleCloseModal)
      modalRoot.current = null        
      }
    }
  }, [])

    return (
    <>
        <Toolbar className={classes.toolBar}>
            <IconButton  onClick={handleClick}>
                {isOpen ? <ArrowBackIcon className={classes.iconArrow} /> : <MenuIcon className={classes.iconBtn} />}
            </IconButton>
          <Search>
                <SearchIconWrapper>
                    <SearchIcon />
                </SearchIconWrapper>
                <StyledInputBase
                 onFocus={handleFocus}
                 onChange={handleSearch}
                 placeholder="Search"
                 inputProps={{ 'aria-label': 'search' }}
                />
            </Search>
        </Toolbar>
        {isOpen ? <SearchBar /> :
          <ChatsList handleEnterOpenMenuSm={handleEnterOpenMenuSm}
            handleLeaveCloseMenuSm={handleLeaveCloseMenuSm} />}
        {isMenu && modalRoot.current && createPortal(<MenuBar />, modalRoot.current)}
        {isMenuSm&&<SmallMenuBar />}
    </>
    )
}

export default ContactsBar